@@ -1,7 +1,6 @@
 /*============================================================================
-
-  WCSLIB 5.19 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2018, Mark Calabretta
+  WCSLIB 7.3 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2020, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -22,10 +21,10 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: lin.h,v 5.19 2018/07/26 15:37:04 mcalabre Exp $
+  $Id: lin.h,v 7.3.1.2 2020/08/17 11:19:09 mcalabre Exp mcalabre $
 *=============================================================================
 *
-* WCSLIB 5.19 - C routines that implement the FITS World Coordinate System
+* WCSLIB 7.3 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -532,7 +531,7 @@
 *
 *     Here, after the distortion function parameters etc. are copied into
 *     dispre, dispre is assigned using lindist() which takes control of the
-*     allocated memory.  It will be free'd later when linfree() is invoked on
+*     allocated memory.  It will be freed later when linfree() is invoked on
 *     the linprm struct.
 *
 *     Consider also the following erroneous code:
@@ -619,44 +618,44 @@ extern "C" {
 extern const char *lin_errmsg[];
 
 enum lin_errmsg_enum {
-  LINERR_SUCCESS      = 0,	/* Success. */
-  LINERR_NULL_POINTER = 1,	/* Null linprm pointer passed. */
-  LINERR_MEMORY       = 2,	/* Memory allocation failed. */
-  LINERR_SINGULAR_MTX = 3,	/* PCi_ja matrix is singular. */
-  LINERR_DISTORT_INIT = 4,	/* Failed to initialise distortions. */
-  LINERR_DISTORT      = 5,	/* Distort error. */
-  LINERR_DEDISTORT    = 6	/* De-distort error. */
+  LINERR_SUCCESS      = 0,	// Success.
+  LINERR_NULL_POINTER = 1,	// Null linprm pointer passed.
+  LINERR_MEMORY       = 2,	// Memory allocation failed.
+  LINERR_SINGULAR_MTX = 3,	// PCi_ja matrix is singular.
+  LINERR_DISTORT_INIT = 4,	// Failed to initialise distortions.
+  LINERR_DISTORT      = 5,	// Distort error.
+  LINERR_DEDISTORT    = 6	// De-distort error.
 };
 
 struct linprm {
-  /* Initialization flag (see the prologue above).                          */
-  /*------------------------------------------------------------------------*/
-  int flag;			/* Set to zero to force initialization.     */
+  // Initialization flag (see the prologue above).
+  //--------------------------------------------------------------------------
+  int flag;			// Set to zero to force initialization.
 
-  /* Parameters to be provided (see the prologue above).                    */
-  /*------------------------------------------------------------------------*/
-  int naxis;			/* The number of axes, given by NAXIS.      */
-  double *crpix;		/* CRPIXja keywords for each pixel axis.    */
-  double *pc;			/* PCi_ja  linear transformation matrix.    */
-  double *cdelt;		/* CDELTia keywords for each coord axis.    */
-  struct disprm *dispre;	/* Prior   distortion parameters, if any.   */
-  struct disprm *disseq;	/* Sequent distortion parameters, if any.   */
+  // Parameters to be provided (see the prologue above).
+  //--------------------------------------------------------------------------
+  int naxis;			// The number of axes, given by NAXIS.
+  double *crpix;		// CRPIXja keywords for each pixel axis.
+  double *pc;			// PCi_ja  linear transformation matrix.
+  double *cdelt;		// CDELTia keywords for each coord axis.
+  struct disprm *dispre;	// Prior   distortion parameters, if any.
+  struct disprm *disseq;	// Sequent distortion parameters, if any.
 
-  /* Information derived from the parameters supplied.                      */
-  /*------------------------------------------------------------------------*/
-  double *piximg;		/* Product of CDELTia and PCi_ja matrices.  */
-  double *imgpix;		/* Inverse of the piximg matrix.            */
-  int    i_naxis;		/* Dimension of piximg and imgpix.          */
-  int    unity;			/* True if the PCi_ja matrix is unity.      */
-  int    affine;		/* True if there are no distortions.        */
-  int    simple;		/* True if unity and no distortions.        */
+  // Information derived from the parameters supplied.
+  //--------------------------------------------------------------------------
+  double *piximg;		// Product of CDELTia and PCi_ja matrices.
+  double *imgpix;		// Inverse of the piximg matrix.
+  int    i_naxis;		// Dimension of piximg and imgpix.
+  int    unity;			// True if the PCi_ja matrix is unity.
+  int    affine;		// True if there are no distortions.
+  int    simple;		// True if unity and no distortions.
 
-  /* Error handling, if enabled.                                            */
-  /*------------------------------------------------------------------------*/
+  // Error handling, if enabled.
+  //--------------------------------------------------------------------------
   struct wcserr *err;
 
-  /* Private - the remainder are for internal use.                          */
-  /*------------------------------------------------------------------------*/
+  // Private - the remainder are for internal use.
+  //--------------------------------------------------------------------------
   double *tmpcrd;
 
   int    m_flag, m_naxis;
@@ -664,7 +663,7 @@ struct linprm {
   struct disprm *m_dispre, *m_disseq;
 };
 
-/* Size of the linprm struct in int units, used by the Fortran wrappers. */
+// Size of the linprm struct in int units, used by the Fortran wrappers.
 #define LINLEN (sizeof(struct linprm)/sizeof(int))
 
 
@@ -701,7 +700,7 @@ int linwarp(struct linprm *lin, const double pixblc[], const double pixtrc[],
 int matinv(int n, const double mat[], double inv[]);
 
 
-/* Deprecated. */
+// Deprecated.
 #define linini_errmsg lin_errmsg
 #define lincpy_errmsg lin_errmsg
 #define linfree_errmsg lin_errmsg
@@ -714,4 +713,4 @@ int matinv(int n, const double mat[], double inv[]);
 }
 #endif
 
-#endif /* WCSLIB_LIN */
+#endif // WCSLIB_LIN
